@@ -434,16 +434,42 @@ resizer.onResize = function ()
 	}
 	else
 	{
-		$('#FrontPageManagerLeft').masonry( 'destroy' );
+		try
+		{
+			$('#FrontPageManagerLeft').masonry( 'destroy' );
+			$('#portal-column-one').masonry( 'destroy' );
+			$('#portal-column-two').masonry( 'destroy' );
+		}
+	        catch(err)
+		{
+			//Do nothing
+		}
+		
 		Arnolfini.resizeImg("#FrontPageManagerRight .portletWrapper .portletCollection", "mini");
 		
-		$('#portal-column-one').masonry( 'destroy' );
-		$('#portal-column-two').masonry( 'destroy' );
 		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
-		
 	}
 }
 
+// Test for nth-child(...n) support
+Modernizr.testStyles(" #modernizr div:nth-child(3n){width:10px;} ", function(elem, rule) {
+	var bool = false, divs = elem.getElementsByTagName("div");
+	if (divs.length == 7){
+		var test = window.getComputedStyle ? function(i){
+			return getComputedStyle(divs[i], null)["width"] == "10px";
+		} : function(i){
+			return divs[i].currentStyle["width"] == "10px";
+		};
+		bool = !test(0) && !test(1) && test(2) && !test(3) && !test(4) && test(5) && !test(6);
+	}
+
+	Modernizr.addTest("nthchildn", bool);
+}, 7);
+
+Arnolfini.IEFixNthChild = function () {
+	$(".threecol div.tileItem:nth-child(3n+2)").addClass("threecolNthChild");
+}
+
 $(document).ready(function() {
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
@@ -464,5 +490,10 @@ $(document).ready(function() {
 	}
 	
 	Arnolfini.portletLinks();
+	
+	if (!Modernizr.nthchildn)
+	{
+		Arnolfini.IEFixNthChild();
+	}
 });
 
